@@ -271,10 +271,10 @@ KADateTime AlarmTimeWidget::getDateTime(int* minsFromNow, bool checkExpired, boo
         if (!mDelayTimeEdit->isValid())
         {
             if (showErrorMessage)
-                KAMessageBox::sorry(const_cast<AlarmTimeWidget*>(this), i18nc("@info", "Invalid time"));
+                KAMessageBox::error(const_cast<AlarmTimeWidget*>(this), i18nc("@info", "Invalid time"));
             if (errorWidget)
                 *errorWidget = mDelayTimeEdit;
-            return KADateTime();
+            return {};
         }
         const int delayMins = mDelayTimeEdit->value();
         if (minsFromNow)
@@ -291,18 +291,18 @@ KADateTime AlarmTimeWidget::getDateTime(int* minsFromNow, bool checkExpired, boo
             if (!mDateEdit->date().isValid())
             {
                 if (showErrorMessage)
-                    KAMessageBox::sorry(const_cast<AlarmTimeWidget*>(this), i18nc("@info", "Invalid date"));
+                    KAMessageBox::error(const_cast<AlarmTimeWidget*>(this), i18nc("@info", "Invalid date"));
                 if (errorWidget)
                     *errorWidget = mDateEdit;
             }
             else
             {
                 if (showErrorMessage)
-                    KAMessageBox::sorry(const_cast<AlarmTimeWidget*>(this), i18nc("@info", "Invalid time"));
+                    KAMessageBox::error(const_cast<AlarmTimeWidget*>(this), i18nc("@info", "Invalid time"));
                 if (errorWidget)
                     *errorWidget = mTimeEdit;
             }
-            return KADateTime();
+            return {};
         }
 
         KADateTime result;
@@ -312,10 +312,10 @@ KADateTime AlarmTimeWidget::getDateTime(int* minsFromNow, bool checkExpired, boo
             if (checkExpired  &&  result.date() < now.date())
             {
                 if (showErrorMessage)
-                    KAMessageBox::sorry(const_cast<AlarmTimeWidget*>(this), i18nc("@info", "Alarm date has already expired"));
+                    KAMessageBox::error(const_cast<AlarmTimeWidget*>(this), i18nc("@info", "Alarm date has already expired"));
                 if (errorWidget)
                     *errorWidget = mDateEdit;
-                return KADateTime();
+                return {};
             }
         }
         else
@@ -324,10 +324,10 @@ KADateTime AlarmTimeWidget::getDateTime(int* minsFromNow, bool checkExpired, boo
             if (checkExpired  &&  result <= now.addSecs(1))
             {
                 if (showErrorMessage)
-                    KAMessageBox::sorry(const_cast<AlarmTimeWidget*>(this), i18nc("@info", "Alarm time has already expired"));
+                    KAMessageBox::error(const_cast<AlarmTimeWidget*>(this), i18nc("@info", "Alarm time has already expired"));
                 if (errorWidget)
                     *errorWidget = mTimeEdit;
-                return KADateTime();
+                return {};
             }
         }
         return result;
