@@ -10,7 +10,6 @@
 
 #include "editdlgtypes.h"
 #include "fontcolourbutton.h"
-#include "kalarmapp.h"
 #include "latecancel.h"
 #include "preferences.h"
 #include "reminder.h"
@@ -21,7 +20,6 @@
 #include "lib/checkbox.h"
 #include "lib/shellprocess.h"
 #include "akonadiplugin/akonadiplugin.h"
-#include "kalarm_debug.h"
 
 #include <KLocalizedString>
 #include <KConfigGroup>
@@ -39,8 +37,6 @@
 #include <QDialogButtonBox>
 #include <QSortFilterProxyModel>
 
-using namespace KCal;
-
 
 BirthdayDlg::BirthdayDlg(QWidget* parent)
     : QDialog(parent)
