@@ -1,7 +1,7 @@
 /*
  *  commandoptions.cpp  -  extract command line options
  *  Program:  kalarm
- *  SPDX-FileCopyrightText: 2001-2021 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2001-2022 David Jarvie <djarvie@kde.org>
  *
  *  SPDX-License-Identifier: GPL-2.0-or-later
  */
@@ -9,12 +9,12 @@
 #include "commandoptions.h"
 
 #include "functions.h"
-#include "kalarmapp.h"
 #include "kamail.h"
+#include "preferences.h"
+#include "kalarmcalendar/identities.h"
 #include "kalarm_debug.h"
 
-#include <KAlarmCal/Identities>
-#include <KPIMTextEdit/TextToSpeech>
+#include <kpimtextedit/kpimtextedit-texttospeech.h>
 #include <KLocalizedString>
 
 #include <QCommandLineParser>
@@ -23,13 +23,88 @@
 
 namespace
 {
+enum Option
+{
+    ACK_CONFIRM,
+    ATTACH,
+    AUTO_CLOSE,
+    BCC,
+    BEEP,
+    COLOUR,
+    COLOURFG,
+    OptCANCEL_EVENT,
+    DISABLE,
+    DISABLE_ALL,
+    EXEC,
+    EXEC_DISPLAY,
+    OptEDIT,
+    EDIT_NEW_DISPLAY,
+    EDIT_NEW_COMMAND,
+    EDIT_NEW_EMAIL,
+    EDIT_NEW_AUDIO,
+    OptEDIT_NEW_PRESET,
+    OptFILE,
+    FROM_ID,
+    INTERVAL,
+    KORGANIZER,
+    LATE_CANCEL,
+    OptLIST,
+    LOGIN,
+    MAIL,
+    NAME,
+    NOTIFY,
+    PLAY,
+    PLAY_REPEAT,
+    RECURRENCE,
+    REMINDER,
+    REMINDER_ONCE,
+    REPEAT,
+#if KPIMTEXTEDIT_TEXT_TO_SPEECH
+    SPEAK,
+#endif
+    SUBJECT,
+#ifndef NDEBUG
+    TEST_SET_TIME,
+#endif
+    TIME,
+    OptTRAY,
+    OptTRIGGER_EVENT,
+    UNTIL,
+    VOLUME,
+    Num_Options,       // number of Option values
+    Opt_Message        // special value representing "message"
+};
+
 bool convInterval(const QString& timeParam, KARecurrence::Type&, int& timeInterval, bool allowMonthYear = false);
 }
 
+class CommandOptions::Private
+{
+public:
+    explicit Private(CommandOptions* parent)
+        : p(parent)
+    {}
+    bool    checkCommand(Option, Command, EditAlarmDlg::Type = EditAlarmDlg::NO_TYPE);
+    void    setError(const QString& error);
+    void    setErrorRequires(Option opt, Option opt2, Option opt3 = Num_Options);
+    void    setErrorParameter(Option);
+    void    setErrorIncompatible(Option opt1, Option opt2);
+    void    checkEditType(EditAlarmDlg::Type type, Option opt)
+                          { checkEditType(type, EditAlarmDlg::NO_TYPE, opt); }
+    void    checkEditType(EditAlarmDlg::Type, EditAlarmDlg::Type, Option);
+    QString optionName(Option, bool shortName = false) const;
+
+    CommandOptions* const p;
+    Option mCommandOpt;             // option for the selected command
+};
+
+/*===========================================================================*/
+
 CommandOptions* CommandOptions::mFirstInstance = nullptr;
 
 CommandOptions::CommandOptions()
-    : mOptions(Num_Options, nullptr)
+    : d(new Private(this))
+    , mOptions(Num_Options, nullptr)
     , mBgColour(Preferences::defaultBgColour())
     , mFgColour(Preferences::defaultFgColour())
     , mFlags(KAEvent::DEFAULT_FONT)
@@ -109,7 +184,7 @@ QStringList CommandOptions::setOptions(QCommandLineParser* parser, const QString
               = new QCommandLineOption(QStringLiteral("edit-new-preset"),
                                        i18n("Display the alarm edit dialog, preset with a template"),
                                        QStringLiteral("templateName"));
-    mOptions[FILE]
+    mOptions[OptFILE]
               = new QCommandLineOption(QStringList{QStringLiteral("f"), QStringLiteral("file")},
                                        i18n("File to display"),
                                        QStringLiteral("url"));
@@ -169,9 +244,11 @@ QStringList CommandOptions::setOptions(QCommandLineParser* parser, const QString
               = new QCommandLineOption(QStringList{QStringLiteral("r"), QStringLiteral("repeat")},
                                        i18n("Number of times to repeat alarm (including initial occasion)"),
                                        QStringLiteral("count"));
+#if KPIMTEXTEDIT_TEXT_TO_SPEECH
     mOptions[SPEAK]
               = new QCommandLineOption(QStringList{QStringLiteral("s"), QStringLiteral("speak")},
                                        i18n("Speak the message when it is displayed"));
+#endif
     mOptions[SUBJECT]
               = new QCommandLineOption(QStringList{QStringLiteral("S"), QStringLiteral("subject")},
                                        i18n("Email subject line"),
@@ -221,8 +298,8 @@ QStringList CommandOptions::setOptions(QCommandLineParser* parser, const QString
         if (arg == QLatin1String("--nofork"))
             continue;     // Ignore debugging option
         mNonExecArguments << arg;
-        if (arg == optionName(EXEC)  ||  arg == optionName(EXEC, true)
-        ||  arg == optionName(EXEC_DISPLAY)  ||  arg == optionName(EXEC_DISPLAY, true))
+        if (arg == d->optionName(EXEC)  ||  arg == d->optionName(EXEC, true)
+        ||  arg == d->optionName(EXEC_DISPLAY)  ||  arg == d->optionName(EXEC_DISPLAY, true))
         {
             // All following arguments (including ones beginning with '-')
             // belong to this option. QCommandLineParser can't handle this, so
@@ -244,7 +321,7 @@ void CommandOptions::parse()
     {
         qCWarning(KALARM_LOG) << "CommandOptions::parse:" << mParser->errorText();
         mError.clear();
-        setError(mParser->errorText());
+        d->setError(mParser->errorText());
     }
     else
         mParser->process(mNonExecArguments);
@@ -260,58 +337,58 @@ void CommandOptions::process()
     {
         const QString time = mParser->value(*mOptions.at(TEST_SET_TIME));
         if (!KAlarm::convertTimeString(time.toLatin1(), mSimulationTime, KADateTime::realCurrentLocalDateTime(), true))
-            setErrorParameter(TEST_SET_TIME);
+            d->setErrorParameter(TEST_SET_TIME);
     }
 #endif
-    if (checkCommand(OptTRAY, TRAY))
+    if (d->checkCommand(OptTRAY, TRAY))
     {
     }
-    if (checkCommand(OptLIST, LIST))
+    if (d->checkCommand(OptLIST, LIST))
     {
         if (!mParser->positionalArguments().empty())
-            setErrorParameter(OptLIST);
+            d->setErrorParameter(OptLIST);
     }
-    if (checkCommand(OptTRIGGER_EVENT, TRIGGER_EVENT)
-    ||  checkCommand(OptCANCEL_EVENT, CANCEL_EVENT)
-    ||  checkCommand(OptEDIT, EDIT))
+    if (d->checkCommand(OptTRIGGER_EVENT, TRIGGER_EVENT)
+    ||  d->checkCommand(OptCANCEL_EVENT, CANCEL_EVENT)
+    ||  d->checkCommand(OptEDIT, EDIT))
     {
         // Fetch the resource and event IDs. The supplied ID is the event ID,
         // optionally prefixed by the resource ID followed by a colon delimiter.
-        mResourceId = EventId::extractIDs(mParser->value(*mOptions.at(mCommandOpt)), mEventId);
+        mResourceId = EventId::extractIDs(mParser->value(*mOptions.at(d->mCommandOpt)), mEventId);
     }
-    if (checkCommand(OptEDIT_NEW_PRESET, EDIT_NEW_PRESET))
+    if (d->checkCommand(OptEDIT_NEW_PRESET, EDIT_NEW_PRESET))
     {
-        mName = mParser->value(*mOptions.at(mCommandOpt));
+        mName = mParser->value(*mOptions.at(d->mCommandOpt));
     }
-    if (checkCommand(FILE, NEW))
+    if (d->checkCommand(OptFILE, NEW))
     {
         mEditType      = EditAlarmDlg::DISPLAY;
         mEditAction    = KAEvent::FILE;
         mEditActionSet = true;
-        mText          = mParser->value(*mOptions.at(mCommandOpt));
+        mText          = mParser->value(*mOptions.at(d->mCommandOpt));
     }
-    if (checkCommand(EXEC_DISPLAY, NEW))
+    if (d->checkCommand(EXEC_DISPLAY, NEW))
     {
         mEditType      = EditAlarmDlg::DISPLAY;
         mEditAction    = KAEvent::COMMAND;
         mEditActionSet = true;
         mFlags        |= KAEvent::DISPLAY_COMMAND;
-        mText          = mParser->value(*mOptions.at(mCommandOpt)) + QLatin1String(" ") + mExecArguments.join(QLatin1Char(' '));
+        mText          = mParser->value(*mOptions.at(d->mCommandOpt)) + QLatin1String(" ") + mExecArguments.join(QLatin1Char(' '));
     }
-    if (checkCommand(EXEC, NEW))
+    if (d->checkCommand(EXEC, NEW))
     {
         mEditType      = EditAlarmDlg::COMMAND;
         mEditAction    = KAEvent::COMMAND;
         mEditActionSet = true;
-        mText          = mParser->value(*mOptions.at(mCommandOpt)) + QLatin1String(" ") + mExecArguments.join(QLatin1Char(' '));
+        mText          = mParser->value(*mOptions.at(d->mCommandOpt)) + QLatin1String(" ") + mExecArguments.join(QLatin1Char(' '));
     }
-    if (checkCommand(MAIL, NEW))
+    if (d->checkCommand(MAIL, NEW))
     {
         mEditType      = EditAlarmDlg::EMAIL;
         mEditAction    = KAEvent::EMAIL;
         mEditActionSet = true;
     }
-    if (checkCommand(EDIT_NEW_DISPLAY, EDIT_NEW, EditAlarmDlg::DISPLAY))
+    if (d->checkCommand(EDIT_NEW_DISPLAY, EDIT_NEW, EditAlarmDlg::DISPLAY))
     {
         mEditType = EditAlarmDlg::DISPLAY;
         if (!mEditActionSet  ||  (mEditAction != KAEvent::COMMAND && mEditAction != KAEvent::FILE))
@@ -323,19 +400,19 @@ void CommandOptions::process()
         if (!args.empty())
             mText = args[0];
     }
-    if (checkCommand(EDIT_NEW_COMMAND, EDIT_NEW))
+    if (d->checkCommand(EDIT_NEW_COMMAND, EDIT_NEW))
     {
         mEditType      = EditAlarmDlg::COMMAND;
         mEditAction    = KAEvent::COMMAND;
         mEditActionSet = true;
     }
-    if (checkCommand(EDIT_NEW_EMAIL, EDIT_NEW, EditAlarmDlg::EMAIL))
+    if (d->checkCommand(EDIT_NEW_EMAIL, EDIT_NEW, EditAlarmDlg::EMAIL))
     {
         mEditType      = EditAlarmDlg::EMAIL;
         mEditAction    = KAEvent::EMAIL;
         mEditActionSet = true;
     }
-    if (checkCommand(EDIT_NEW_AUDIO, EDIT_NEW, EditAlarmDlg::AUDIO))
+    if (d->checkCommand(EDIT_NEW_AUDIO, EDIT_NEW, EditAlarmDlg::AUDIO))
     {
         mEditType      = EditAlarmDlg::AUDIO;
         mEditAction    = KAEvent::AUDIO;
@@ -345,7 +422,7 @@ void CommandOptions::process()
     {
         if (mParser->positionalArguments().empty())
         {
-            if (checkCommand(PLAY, NEW) || checkCommand(PLAY_REPEAT, NEW))
+            if (d->checkCommand(PLAY, NEW) || d->checkCommand(PLAY_REPEAT, NEW))
             {
                 mEditType      = EditAlarmDlg::AUDIO;
                 mEditAction    = KAEvent::AUDIO;
@@ -356,7 +433,7 @@ void CommandOptions::process()
         {
             qCDebug(KALARM_LOG) << "CommandOptions::process: Message";
             mCommand       = NEW;
-            mCommandOpt    = Opt_Message;
+            d->mCommandOpt = Opt_Message;
             mEditType      = EditAlarmDlg::DISPLAY;
             mEditAction    = KAEvent::MESSAGE;
             mEditActionSet = true;
@@ -374,7 +451,7 @@ void CommandOptions::process()
         {
             QString a(addr);
             if (!KAMail::checkAddress(a))
-                setError(xi18nc("@info:shell", "<icode>%1</icode>: invalid email address", optionName(MAIL)));
+                d->setError(xi18nc("@info:shell", "<icode>%1</icode>: invalid email address", d->optionName(MAIL)));
             KCalendarCore::Person person(QString(), addr);
             mAddressees += person;
         }
@@ -388,34 +465,36 @@ void CommandOptions::process()
     if (mParser->isSet(*mOptions.at(DISABLE_ALL)))
     {
         if (mCommand == TRIGGER_EVENT  ||  mCommand == LIST)
-            setErrorIncompatible(DISABLE_ALL, mCommandOpt);
+            d->setErrorIncompatible(DISABLE_ALL, d->mCommandOpt);
         mDisableAll = true;
     }
 
     // Check that other options are only specified for the
     // correct main command options.
-    checkEditType(EditAlarmDlg::DISPLAY, COLOUR);
-    checkEditType(EditAlarmDlg::DISPLAY, COLOURFG);
-    checkEditType(EditAlarmDlg::DISPLAY, EditAlarmDlg::AUDIO, PLAY);
-    checkEditType(EditAlarmDlg::DISPLAY, EditAlarmDlg::AUDIO, PLAY_REPEAT);
-    checkEditType(EditAlarmDlg::DISPLAY, EditAlarmDlg::AUDIO, VOLUME);
-    checkEditType(EditAlarmDlg::DISPLAY, SPEAK);
-    checkEditType(EditAlarmDlg::DISPLAY, BEEP);
-    checkEditType(EditAlarmDlg::DISPLAY, REMINDER);
-    checkEditType(EditAlarmDlg::DISPLAY, REMINDER_ONCE);
-    checkEditType(EditAlarmDlg::DISPLAY, ACK_CONFIRM);
-    checkEditType(EditAlarmDlg::DISPLAY, AUTO_CLOSE);
-    checkEditType(EditAlarmDlg::DISPLAY, NOTIFY);
-    checkEditType(EditAlarmDlg::EMAIL, SUBJECT);
-    checkEditType(EditAlarmDlg::EMAIL, FROM_ID);
-    checkEditType(EditAlarmDlg::EMAIL, ATTACH);
-    checkEditType(EditAlarmDlg::EMAIL, BCC);
+    d->checkEditType(EditAlarmDlg::DISPLAY, COLOUR);
+    d->checkEditType(EditAlarmDlg::DISPLAY, COLOURFG);
+    d->checkEditType(EditAlarmDlg::DISPLAY, EditAlarmDlg::AUDIO, PLAY);
+    d->checkEditType(EditAlarmDlg::DISPLAY, EditAlarmDlg::AUDIO, PLAY_REPEAT);
+    d->checkEditType(EditAlarmDlg::DISPLAY, EditAlarmDlg::AUDIO, VOLUME);
+#if KPIMTEXTEDIT_TEXT_TO_SPEECH
+    d->checkEditType(EditAlarmDlg::DISPLAY, SPEAK);
+#endif
+    d->checkEditType(EditAlarmDlg::DISPLAY, BEEP);
+    d->checkEditType(EditAlarmDlg::DISPLAY, REMINDER);
+    d->checkEditType(EditAlarmDlg::DISPLAY, REMINDER_ONCE);
+    d->checkEditType(EditAlarmDlg::DISPLAY, ACK_CONFIRM);
+    d->checkEditType(EditAlarmDlg::DISPLAY, AUTO_CLOSE);
+    d->checkEditType(EditAlarmDlg::DISPLAY, NOTIFY);
+    d->checkEditType(EditAlarmDlg::EMAIL, SUBJECT);
+    d->checkEditType(EditAlarmDlg::EMAIL, FROM_ID);
+    d->checkEditType(EditAlarmDlg::EMAIL, ATTACH);
+    d->checkEditType(EditAlarmDlg::EMAIL, BCC);
 
     switch (mCommand)
     {
         case EDIT_NEW:
             if (mParser->isSet(*mOptions.at(DISABLE)))
-                setErrorIncompatible(DISABLE, mCommandOpt);
+                d->setErrorIncompatible(DISABLE, d->mCommandOpt);
             // Fall through to NEW
             Q_FALLTHROUGH();
         case NEW:
@@ -435,7 +514,7 @@ void CommandOptions::process()
                     colourText.replace(0, 2, QStringLiteral("#"));
                 mBgColour.setNamedColor(colourText);
                 if (!mBgColour.isValid())
-                    setErrorParameter(COLOUR);
+                    d->setErrorParameter(COLOUR);
             }
             if (mParser->isSet(*mOptions.at(COLOURFG)))
             {
@@ -446,14 +525,14 @@ void CommandOptions::process()
                     colourText.replace(0, 2, QStringLiteral("#"));
                 mFgColour.setNamedColor(colourText);
                 if (!mFgColour.isValid())
-                    setErrorParameter(COLOURFG);
+                    d->setErrorParameter(COLOURFG);
             }
 
             if (mParser->isSet(*mOptions.at(TIME)))
             {
                 const QByteArray dateTime = mParser->value(*mOptions.at(TIME)).toLocal8Bit();
                 if (!KAlarm::convertTimeString(dateTime, mAlarmTime))
-                    setErrorParameter(TIME);
+                    d->setErrorParameter(TIME);
             }
             else
                 mAlarmTime = KADateTime::currentLocalDateTime();
@@ -462,9 +541,9 @@ void CommandOptions::process()
             if (haveRecurrence)
             {
                 if (mParser->isSet(*mOptions.at(LOGIN)))
-                    setErrorIncompatible(LOGIN, RECURRENCE);
+                    d->setErrorIncompatible(LOGIN, RECURRENCE);
                 else if (mParser->isSet(*mOptions.at(UNTIL)))
-                    setErrorIncompatible(UNTIL, RECURRENCE);
+                    d->setErrorIncompatible(UNTIL, RECURRENCE);
                 const QString rule = mParser->value(*mOptions.at(RECURRENCE));
                 mRecurrence = new KARecurrence;
                 mRecurrence->set(rule);
@@ -475,33 +554,32 @@ void CommandOptions::process()
                 int count = 0;
                 KADateTime endTime;
                 if (mParser->isSet(*mOptions.at(LOGIN)))
-                    setErrorIncompatible(LOGIN, INTERVAL);
+                    d->setErrorIncompatible(LOGIN, INTERVAL);
                 bool ok;
                 if (mParser->isSet(*mOptions.at(REPEAT)))
                 {
                     count = mParser->value(*mOptions.at(REPEAT)).toInt(&ok);
                     if (!ok || !count || count < -1 || (count < 0 && haveRecurrence))
-                        setErrorParameter(REPEAT);
+                        d->setErrorParameter(REPEAT);
                 }
                 else if (haveRecurrence)
-                    setErrorRequires(INTERVAL, REPEAT);
+                    d->setErrorRequires(INTERVAL, REPEAT);
                 else if (mParser->isSet(*mOptions.at(UNTIL)))
                 {
                     count = 0;
                     const QByteArray dateTime = mParser->value(*mOptions.at(UNTIL)).toLocal8Bit();
-                    bool ok;
                     if (mParser->isSet(*mOptions.at(TIME)))
                         ok = KAlarm::convertTimeString(dateTime, endTime, mAlarmTime);
                     else
                         ok = KAlarm::convertTimeString(dateTime, endTime);
                     if (!ok)
-                        setErrorParameter(UNTIL);
+                        d->setErrorParameter(UNTIL);
                     else if (mAlarmTime.isDateOnly()  &&  !endTime.isDateOnly())
-                        setError(xi18nc("@info:shell", "Invalid <icode>%1</icode> parameter for date-only alarm", optionName(UNTIL)));
+                        d->setError(xi18nc("@info:shell", "Invalid <icode>%1</icode> parameter for date-only alarm", d->optionName(UNTIL)));
                     if (!mAlarmTime.isDateOnly()  &&  endTime.isDateOnly())
                         endTime.setTime(QTime(23,59,59));
                     if (endTime < mAlarmTime)
-                        setError(xi18nc("@info:shell", "<icode>%1</icode> earlier than <icode>%2</icode>", optionName(UNTIL), optionName(TIME)));
+                        d->setError(xi18nc("@info:shell", "<icode>%1</icode> earlier than <icode>%2</icode>", d->optionName(UNTIL), d->optionName(TIME)));
                 }
                 else
                     count = -1;
@@ -510,9 +588,9 @@ void CommandOptions::process()
                 int intervalOfType;
                 KARecurrence::Type recurType;
                 if (!convInterval(mParser->value(*mOptions.at(INTERVAL)), recurType, intervalOfType, !haveRecurrence))
-                    setErrorParameter(INTERVAL);
+                    d->setErrorParameter(INTERVAL);
                 else if (mAlarmTime.isDateOnly()  &&  recurType == KARecurrence::MINUTELY)
-                    setError(xi18nc("@info:shell", "Invalid <icode>%1</icode> parameter for date-only alarm", optionName(INTERVAL)));
+                    d->setError(xi18nc("@info:shell", "Invalid <icode>%1</icode> parameter for date-only alarm", d->optionName(INTERVAL)));
 
                 if (haveRecurrence)
                 {
@@ -523,8 +601,8 @@ void CommandOptions::process()
                         mRepeatInterval = KCalendarCore::Duration(intervalOfType * 60);
                         const KCalendarCore::Duration longestInterval = mRecurrence->longestInterval();
                         if (mRepeatInterval * count > longestInterval)
-                            setError(xi18nc("@info:shell", "Invalid <icode>%1</icode> and <icode>%2</icode> parameters: repetition is longer than <icode>%3</icode> interval",
-                                           optionName(INTERVAL), optionName(REPEAT), optionName(RECURRENCE)));
+                            d->setError(xi18nc("@info:shell", "Invalid <icode>%1</icode> and <icode>%2</icode> parameters: repetition is longer than <icode>%3</icode> interval",
+                                           d->optionName(INTERVAL), d->optionName(REPEAT), d->optionName(RECURRENCE)));
                         mRepeatCount = count;
                     }
                 }
@@ -539,9 +617,9 @@ void CommandOptions::process()
             else
             {
                 if (mParser->isSet(*mOptions.at(REPEAT)))
-                    setErrorRequires(REPEAT, INTERVAL);
+                    d->setErrorRequires(REPEAT, INTERVAL);
                 else if (mParser->isSet(*mOptions.at(UNTIL)))
-                    setErrorRequires(UNTIL, INTERVAL);
+                    d->setErrorRequires(UNTIL, INTERVAL);
             }
 
             const bool audioRepeat = mParser->isSet(*mOptions.at(PLAY_REPEAT));
@@ -550,36 +628,38 @@ void CommandOptions::process()
                 // Play a sound with the alarm
                 const Option opt = audioRepeat ? PLAY_REPEAT : PLAY;
                 if (audioRepeat  &&  mParser->isSet(*mOptions.at(PLAY)))
-                    setErrorIncompatible(PLAY, PLAY_REPEAT);
+                    d->setErrorIncompatible(PLAY, PLAY_REPEAT);
                 if (mParser->isSet(*mOptions.at(BEEP)))
-                    setErrorIncompatible(BEEP, opt);
+                    d->setErrorIncompatible(BEEP, opt);
+#if KPIMTEXTEDIT_TEXT_TO_SPEECH
                 else if (mParser->isSet(*mOptions.at(SPEAK)))
-                    setErrorIncompatible(SPEAK, opt);
+                    d->setErrorIncompatible(SPEAK, opt);
+#endif
                 mAudioFile = mParser->value(*mOptions.at(audioRepeat ? PLAY_REPEAT : PLAY));
                 if (mParser->isSet(*mOptions.at(VOLUME)))
                 {
                     bool ok;
                     const int volumepc = mParser->value(*mOptions.at(VOLUME)).toInt(&ok);
                     if (!ok  ||  volumepc < 0  ||  volumepc > 100)
-                        setErrorParameter(VOLUME);
+                        d->setErrorParameter(VOLUME);
                     mAudioVolume = static_cast<float>(volumepc) / 100;
                 }
             }
             else if (mParser->isSet(*mOptions.at(VOLUME)))
-                setErrorRequires(VOLUME, PLAY, PLAY_REPEAT);
+                d->setErrorRequires(VOLUME, PLAY, PLAY_REPEAT);
+#if KPIMTEXTEDIT_TEXT_TO_SPEECH
             if (mParser->isSet(*mOptions.at(SPEAK)))
             {
                 if (mParser->isSet(*mOptions.at(BEEP)))
-                    setErrorIncompatible(BEEP, SPEAK);
-                else if (!KPIMTextEdit::TextToSpeech::self()->isReady())
-                    setError(xi18nc("@info:shell", "<icode>%1</icode> requires KAlarm to be compiled with QTextToSpeech support", optionName(SPEAK)));
+                    d->setErrorIncompatible(BEEP, SPEAK);
             }
+#endif
             const bool onceOnly = mParser->isSet(*mOptions.at(REMINDER_ONCE));
             if (mParser->isSet(*mOptions.at(REMINDER))  ||  onceOnly)
             {
                 // Issue a reminder alarm in advance of or after the main alarm
                 if (onceOnly  &&  mParser->isSet(*mOptions.at(REMINDER)))
-                    setErrorIncompatible(REMINDER, REMINDER_ONCE);
+                    d->setErrorIncompatible(REMINDER, REMINDER_ONCE);
                 const Option opt = onceOnly ? REMINDER_ONCE : REMINDER;
                 KARecurrence::Type recurType;
                 QString optval = mParser->value(*mOptions.at(onceOnly ? REMINDER_ONCE : REMINDER));
@@ -587,9 +667,9 @@ void CommandOptions::process()
                 if (after)
                     optval.remove(0, 1);   // it's a reminder after the main alarm
                 if (!convInterval(optval, recurType, mReminderMinutes))
-                    setErrorParameter(opt);
+                    d->setErrorParameter(opt);
                 else if (recurType == KARecurrence::MINUTELY  &&  mAlarmTime.isDateOnly())
-                    setError(xi18nc("@info:shell", "Invalid <icode>%1</icode> parameter for date-only alarm", optionName(opt)));
+                    d->setError(xi18nc("@info:shell", "Invalid <icode>%1</icode> parameter for date-only alarm", d->optionName(opt)));
                 if (after)
                     mReminderMinutes = -mReminderMinutes;
                 if (onceOnly)
@@ -601,23 +681,23 @@ void CommandOptions::process()
                 KARecurrence::Type recurType;
                 const bool ok = convInterval(mParser->value(*mOptions.at(LATE_CANCEL)), recurType, mLateCancel);
                 if (!ok)
-                    setErrorParameter(LATE_CANCEL);
+                    d->setErrorParameter(LATE_CANCEL);
             }
             else if (mParser->isSet(*mOptions.at(AUTO_CLOSE)))
-                setErrorRequires(AUTO_CLOSE, LATE_CANCEL);
+                d->setErrorRequires(AUTO_CLOSE, LATE_CANCEL);
 
             if (mParser->isSet(*mOptions.at(NOTIFY)))
             {
                 if (mParser->isSet(*mOptions.at(COLOUR)))
-                    setErrorIncompatible(NOTIFY, COLOUR);
+                    d->setErrorIncompatible(NOTIFY, COLOUR);
                 if (mParser->isSet(*mOptions.at(COLOURFG)))
-                    setErrorIncompatible(NOTIFY, COLOURFG);
+                    d->setErrorIncompatible(NOTIFY, COLOURFG);
                 if (mParser->isSet(*mOptions.at(ACK_CONFIRM)))
-                    setErrorIncompatible(NOTIFY, ACK_CONFIRM);
+                    d->setErrorIncompatible(NOTIFY, ACK_CONFIRM);
                 if (mParser->isSet(*mOptions.at(PLAY)))
-                    setErrorIncompatible(NOTIFY, PLAY);
+                    d->setErrorIncompatible(NOTIFY, PLAY);
                 if (mParser->isSet(*mOptions.at(AUTO_CLOSE)))
-                    setErrorIncompatible(NOTIFY, AUTO_CLOSE);
+                    d->setErrorIncompatible(NOTIFY, AUTO_CLOSE);
             }
 
             if (mParser->isSet(*mOptions.at(ACK_CONFIRM)))
@@ -626,8 +706,10 @@ void CommandOptions::process()
                 mFlags |= KAEvent::AUTO_CLOSE;
             if (mParser->isSet(*mOptions.at(BEEP)))
                 mFlags |= KAEvent::BEEP;
+#if KPIMTEXTEDIT_TEXT_TO_SPEECH
             if (mParser->isSet(*mOptions.at(SPEAK)))
                 mFlags |= KAEvent::SPEAK;
+#endif
             if (mParser->isSet(*mOptions.at(NOTIFY)))
                 mFlags |= KAEvent::NOTIFY;
             if (mParser->isSet(*mOptions.at(KORGANIZER)))
@@ -652,51 +734,53 @@ void CommandOptions::process()
             qCDebug(KALARM_LOG) << "CommandOptions::process: Interactive";
             QStringList errors;
             if (mParser->isSet(*mOptions.at(ACK_CONFIRM)))
-                errors << optionName(ACK_CONFIRM);
+                errors << d->optionName(ACK_CONFIRM);
             if (mParser->isSet(*mOptions.at(ATTACH)))
-                errors << optionName(ATTACH);
+                errors << d->optionName(ATTACH);
             if (mParser->isSet(*mOptions.at(AUTO_CLOSE)))
-                errors << optionName(AUTO_CLOSE);
+                errors << d->optionName(AUTO_CLOSE);
             if (mParser->isSet(*mOptions.at(BCC)))
-                errors << optionName(BCC);
+                errors << d->optionName(BCC);
             if (mParser->isSet(*mOptions.at(BEEP)))
-                errors << optionName(BEEP);
+                errors << d->optionName(BEEP);
             if (mParser->isSet(*mOptions.at(COLOUR)))
-                errors << optionName(COLOUR);
+                errors << d->optionName(COLOUR);
             if (mParser->isSet(*mOptions.at(COLOURFG)))
-                errors << optionName(COLOURFG);
+                errors << d->optionName(COLOURFG);
             if (mParser->isSet(*mOptions.at(DISABLE)))
-                errors << optionName(DISABLE);
+                errors << d->optionName(DISABLE);
             if (mParser->isSet(*mOptions.at(FROM_ID)))
-                errors << optionName(FROM_ID);
+                errors << d->optionName(FROM_ID);
             if (mParser->isSet(*mOptions.at(KORGANIZER)))
-                errors << optionName(KORGANIZER);
+                errors << d->optionName(KORGANIZER);
             if (mParser->isSet(*mOptions.at(LATE_CANCEL)))
-                errors << optionName(LATE_CANCEL);
+                errors << d->optionName(LATE_CANCEL);
             if (mParser->isSet(*mOptions.at(LOGIN)))
-                errors << optionName(LOGIN);
+                errors << d->optionName(LOGIN);
             if (mParser->isSet(*mOptions.at(NAME)))
-                errors << optionName(NAME);
+                errors << d->optionName(NAME);
             if (mParser->isSet(*mOptions.at(NOTIFY)))
-                errors << optionName(NOTIFY);
+                errors << d->optionName(NOTIFY);
             if (mParser->isSet(*mOptions.at(PLAY)))
-                errors << optionName(PLAY);
+                errors << d->optionName(PLAY);
             if (mParser->isSet(*mOptions.at(PLAY_REPEAT)))
-                errors << optionName(PLAY_REPEAT);
+                errors << d->optionName(PLAY_REPEAT);
             if (mParser->isSet(*mOptions.at(REMINDER)))
-                errors << optionName(REMINDER);
+                errors << d->optionName(REMINDER);
             if (mParser->isSet(*mOptions.at(REMINDER_ONCE)))
-                errors << optionName(REMINDER_ONCE);
+                errors << d->optionName(REMINDER_ONCE);
+#if KPIMTEXTEDIT_TEXT_TO_SPEECH
             if (mParser->isSet(*mOptions.at(SPEAK)))
-                errors << optionName(SPEAK);
+                errors << d->optionName(SPEAK);
+#endif
             if (mParser->isSet(*mOptions.at(NOTIFY)))
-                errors << optionName(NOTIFY);
+                errors << d->optionName(NOTIFY);
             if (mParser->isSet(*mOptions.at(SUBJECT)))
-                errors << optionName(SUBJECT);
+                errors << d->optionName(SUBJECT);
             if (mParser->isSet(*mOptions.at(TIME)))
-                errors << optionName(TIME);
+                errors << d->optionName(TIME);
             if (mParser->isSet(*mOptions.at(VOLUME)))
-                errors << optionName(VOLUME);
+                errors << d->optionName(VOLUME);
             if (!errors.isEmpty())
                 mError = errors.join(QLatin1Char(' ')) + i18nc("@info:shell", ": option(s) only valid with an appropriate action option or message");
             break;
@@ -706,15 +790,12 @@ void CommandOptions::process()
     }
 
     if (!mError.isEmpty())
-        setError(mError);
+        d->setError(mError);
 }
 
-void CommandOptions::setError(const QString& errmsg)
+QString CommandOptions::commandName() const
 {
-    qCWarning(KALARM_LOG) << "CommandOptions::setError:" << errmsg;
-    mCommand = CMD_ERROR;
-    if (mError.isEmpty())
-        mError = errmsg + i18nc("@info:shell", "\nUse --help to get a list of available command line options.\n");
+    return d->optionName(d->mCommandOpt);
 }
 
 void CommandOptions::printError(const QString& errmsg)
@@ -725,54 +806,6 @@ void CommandOptions::printError(const QString& errmsg)
               << i18nc("@info:shell", "\nUse --help to get a list of available command line options.\n").toLocal8Bit().data();
 }
 
-/******************************************************************************
-* Check if the given command option is specified, and if so set mCommand etc.
-* If another command option has also been detected, issue an error.
-* If 'allowedEditType' is set, supersede any previous specification of that
-* edit type with the given command option - this allows, e.g., --mail to be
-* used along with --edit-new-email so the user can specify addressees.
-*/
-bool CommandOptions::checkCommand(Option command, Command code, EditAlarmDlg::Type allowedEditType)
-{
-    if (!mError.isEmpty()
-    ||  !mParser->isSet(*mOptions.at(command)))
-        return false;
-    if (mCommand != NONE
-    &&  (allowedEditType == EditAlarmDlg::NO_TYPE
-      || (allowedEditType != EditAlarmDlg::NO_TYPE  &&  (mCommand != NEW || mEditType != allowedEditType))))
-        setErrorIncompatible(mCommandOpt, command);
-    qCDebug(KALARM_LOG).nospace() << "CommandOptions::checkCommand: " << optionName(command);
-    mCommand = code;
-    mCommandOpt = command;
-    return true;
-}
-
-// Set the error message to "--opt requires --opt2" or "--opt requires --opt2 or --opt3".
-void CommandOptions::setErrorRequires(Option opt, Option opt2, Option opt3)
-{
-    if (opt3 == Num_Options)
-        setError(xi18nc("@info:shell", "<icode>%1</icode> requires <icode>%2</icode>", optionName(opt), optionName(opt2)));
-    else
-        setError(xi18nc("@info:shell", "<icode>%1</icode> requires <icode>%2</icode> or <icode>%3</icode>", optionName(opt), optionName(opt2), optionName(opt3)));
-}
-
-void CommandOptions::setErrorParameter(Option opt)
-{
-    setError(xi18nc("@info:shell", "Invalid <icode>%1</icode> parameter", optionName(opt)));
-}
-
-void CommandOptions::setErrorIncompatible(Option opt1, Option opt2)
-{
-    setError(xi18nc("@info:shell", "<icode>%1</icode> incompatible with <icode>%2</icode>", optionName(opt1), optionName(opt2)));
-}
-
-void CommandOptions::checkEditType(EditAlarmDlg::Type type1, EditAlarmDlg::Type type2, Option opt)
-{
-    if (mParser->isSet(*mOptions.at(opt))  &&  mCommand != NONE
-    &&  ((mCommand != NEW && mCommand != EDIT_NEW)  ||  (mEditType != type1 && (type2 == EditAlarmDlg::NO_TYPE || mEditType != type2))))
-        setErrorIncompatible(opt, mCommandOpt);
-}
-
 // Fetch one of the arguments (i.e. not belonging to any option).
 QString CommandOptions::arg(int n)
 {
@@ -780,13 +813,70 @@ QString CommandOptions::arg(int n)
     return (n < args.size()) ? args[n] : QString();
 }
 
-QString CommandOptions::optionName(Option opt, bool shortName) const
+/*===========================================================================*/
+
+void CommandOptions::Private::setError(const QString& errmsg)
+{
+    qCWarning(KALARM_LOG) << "CommandOptions::setError:" << errmsg;
+    p->mCommand = CMD_ERROR;
+    if (p->mError.isEmpty())
+        p->mError = errmsg + i18nc("@info:shell", "\nUse --help to get a list of available command line options.\n");
+}
+
+/******************************************************************************
+* Check if the given command option is specified, and if so set mCommand etc.
+* If another command option has also been detected, issue an error.
+* If 'allowedEditType' is set, supersede any previous specification of that
+* edit type with the given command option - this allows, e.g., --mail to be
+* used along with --edit-new-email so the user can specify addressees.
+*/
+bool CommandOptions::Private::checkCommand(Option command, Command code, EditAlarmDlg::Type allowedEditType)
+{
+    if (!p->mError.isEmpty()
+    ||  !p->mParser->isSet(*p->mOptions.at(command)))
+        return false;
+    if (p->mCommand != NONE
+    &&  (allowedEditType == EditAlarmDlg::NO_TYPE  ||  (p->mCommand != NEW || p->mEditType != allowedEditType)))
+        setErrorIncompatible(mCommandOpt, command);
+    qCDebug(KALARM_LOG).nospace() << "CommandOptions::checkCommand: " << optionName(command);
+    p->mCommand = code;
+    mCommandOpt = command;
+    return true;
+}
+
+// Set the error message to "--opt requires --opt2" or "--opt requires --opt2 or --opt3".
+void CommandOptions::Private::setErrorRequires(Option opt, Option opt2, Option opt3)
+{
+    if (opt3 == Num_Options)
+        setError(xi18nc("@info:shell", "<icode>%1</icode> requires <icode>%2</icode>", optionName(opt), optionName(opt2)));
+    else
+        setError(xi18nc("@info:shell", "<icode>%1</icode> requires <icode>%2</icode> or <icode>%3</icode>", optionName(opt), optionName(opt2), optionName(opt3)));
+}
+
+void CommandOptions::Private::setErrorParameter(Option opt)
+{
+    setError(xi18nc("@info:shell", "Invalid <icode>%1</icode> parameter", optionName(opt)));
+}
+
+void CommandOptions::Private::setErrorIncompatible(Option opt1, Option opt2)
+{
+    setError(xi18nc("@info:shell", "<icode>%1</icode> incompatible with <icode>%2</icode>", optionName(opt1), optionName(opt2)));
+}
+
+void CommandOptions::Private::checkEditType(EditAlarmDlg::Type type1, EditAlarmDlg::Type type2, Option opt)
+{
+    if (p->mParser->isSet(*p->mOptions.at(opt))  &&  p->mCommand != NONE
+    &&  ((p->mCommand != NEW && p->mCommand != EDIT_NEW)  ||  (p->mEditType != type1 && (type2 == EditAlarmDlg::NO_TYPE || p->mEditType != type2))))
+        setErrorIncompatible(opt, mCommandOpt);
+}
+
+QString CommandOptions::Private::optionName(Option opt, bool shortName) const
 {
     if (opt == Opt_Message)
         return QStringLiteral("message");
-    const QStringList names = mOptions.at(opt)->names();
+    const QStringList names = p->mOptions.at(opt)->names();
     if (names.empty())
-        return QString();
+        return {};
     for (const QString& name : names)
     {
         if (shortName  &&  name.size() == 1)
