@@ -1,7 +1,7 @@
 /*
  *  editdlg.h  -  dialog to create or modify an alarm or alarm template
  *  Program:  kalarm
- *  SPDX-FileCopyrightText: 2001-2021 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2001-2022 David Jarvie <djarvie@kde.org>
  *
  *  SPDX-License-Identifier: GPL-2.0-or-later
  */
@@ -9,10 +9,9 @@
 #pragma once
 
 #include "resources/resource.h"
-
-#include <KAlarmCal/AlarmText>
-#include <KAlarmCal/DateTime>
-#include <KAlarmCal/KAEvent>
+#include "kalarmcalendar/alarmtext.h"
+#include "kalarmcalendar/datetime.h"
+#include "kalarmcalendar/kaevent.h"
 
 #include <QDialog>
 #include <QTime>
@@ -216,5 +215,4 @@ private:
     bool                mSavedShowInKorganizer; // mShowInKorganizer status
 };
 
-
 // vim: et sw=4:
