@@ -1,17 +1,16 @@
 /*
  *  eventid.h  -  KAlarm unique event identifier for resources
  *  Program:  kalarm
- *  SPDX-FileCopyrightText: 2012-2021 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2012-2022 David Jarvie <djarvie@kde.org>
  *
  *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #pragma once
 
+#include "kalarmcalendar/kaevent.h"
 #include "kalarm_debug.h"
 
-#include <KAlarmCal/KAEvent>
-
 using namespace KAlarmCal;
 
 /**
@@ -25,7 +24,7 @@ using namespace KAlarmCal;
 class EventId
 {
 public:
-    EventId()   {}
+    EventId() = default;
     EventId(ResourceId c, const QString& e)
         : mEventId(e)
         , mResourceId(c)
@@ -104,5 +103,4 @@ inline QDebug operator<<(QDebug s, const EventId& id)
     return s.space();
 }
 
-
 // vim: et sw=4:
