@@ -84,6 +84,7 @@ void SpinBox2::init()
     setLayout(layout);
     layout->addWidget(mSpinbox2);
     connect(mSpinbox2, &SpinBox2p::valueChanged, this, &SpinBox2::valueChanged);
+    setFocusProxy(mSpinbox2);
 }
 
 /*===========================================================================*/
@@ -119,6 +120,7 @@ void SpinBox2p::init()
     setFocusProxy(mSpinbox);
     mSpinbox2->setFocusPolicy(Qt::NoFocus);
     mSpinMirror = new SpinMirror(mSpinbox2, mSpinbox, this);
+    mSpinMirror->setFocusPolicy(Qt::NoFocus);
     mSpinbox->installEventFilter(this);
     mSpinbox2->installEventFilter(this);
     connect(mSpinbox, &QSpinBox::valueChanged, this, &SpinBox2p::valueChange);
