@@ -19,14 +19,17 @@
  */
 class MainWindowBase : public KXmlGuiWindow
 {
-        Q_OBJECT
+    Q_OBJECT
 
-    public:
-        explicit MainWindowBase(QWidget* parent = nullptr, Qt::WindowFlags f = Qt::Window);
+public:
+    explicit MainWindowBase(QWidget* parent = nullptr, Qt::WindowFlags f = Qt::Window);
 
-    protected:
-        void enterEvent(QEvent*) override;
+protected:
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    void enterEvent(QEnterEvent *) override;
+#else
+    void enterEvent(QEvent *) override;
+#endif
 };
 
-
 // vim: et sw=4:
