@@ -9,9 +9,7 @@
 #include "messagenotification.h"
 #include "messagedisplayhelper.h"
 
-#include "kalarmapp.h"
 #include "mainwindow.h"
-#include "preferences.h"
 #include "resourcescalendar.h"
 #include "lib/file.h"
 #include "kalarm_debug.h"
@@ -76,7 +74,7 @@ public:
         connect(qApp, &QGuiApplication::saveStateRequest, this, &MNSessionManager::saveState);
 #endif
     }
-    ~MNSessionManager() override {} 
+    ~MNSessionManager() override {}
 
     static void create()
     {
