@@ -58,11 +58,12 @@ using namespace KHolidays;
 #include <KAboutData>
 #include <KStandardGuiItem>
 #include <QIcon>
-#if KDEPIM_HAVE_X11
+#if ENABLE_X11
 #include <KWindowInfo>
 #endif
 #include <KWindowSystem>
 #include <KHelpClient>
+#include <kwidgetsaddons_version.h>
 
 #include <QLabel>
 #include <QCheckBox>
@@ -125,7 +126,7 @@ void KAlarmPrefDlg::display()
     else
     {
         mInstance->restoreTab();
-#if KDEPIM_HAVE_X11
+#if ENABLE_X11
         KWindowInfo info = KWindowInfo(mInstance->winId(), NET::WMGeometry | NET::WMDesktop);
         KWindowSystem::setCurrentDesktop(info.desktop());
 #endif
@@ -212,7 +213,11 @@ void KAlarmPrefDlg::slotApply()
     if (!errmsg.isEmpty())
     {
         setCurrentPage(mEmailPageItem);
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+        if (KAMessageBox::warningYesNo(this, errmsg) != KMessageBox::ButtonCode::PrimaryAction)
+#else
         if (KAMessageBox::warningYesNo(this, errmsg) != KMessageBox::Yes)
+#endif
         {
             mValid = false;
             return;
@@ -222,7 +227,7 @@ void KAlarmPrefDlg::slotApply()
     if (!errmsg.isEmpty())
     {
         setCurrentPage(mEditPageItem);
-        KAMessageBox::sorry(this, errmsg);
+        KAMessageBox::error(this, errmsg);
         mValid = false;
         return;
     }
@@ -263,10 +268,18 @@ void KAlarmPrefDlg::slotDefault()
                          KGuiItem(i18nc("@action:button Reset ALL tabs", "&All")),
                          KGuiItem(i18nc("@action:button Reset the CURRENT tab", "C&urrent"))))
     {
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+        case KMessageBox::ButtonCode::PrimaryAction:
+#else
         case KMessageBox::Yes:
+#endif
             restore(true);   // restore all tabs
             break;
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+        case KMessageBox::ButtonCode::SecondaryAction:
+#else
         case KMessageBox::No:
+#endif
             Preferences::self()->useDefaults(true);
             static_cast<PrefsTabBase*>(currentPage()->widget())->restore(true, false);
             Preferences::self()->useDefaults(false);
@@ -650,7 +663,11 @@ void MiscPrefTab::slotAutostartClicked()
     &&  KAMessageBox::warningYesNo(topLayout()->parentWidget(),
                                    xi18nc("@info", "You should not uncheck this option unless you intend to discontinue use of <application>KAlarm</application>"),
                                    QString(), KStandardGuiItem::cont(), KStandardGuiItem::cancel()
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+                                  ) != KMessageBox::ButtonCode::PrimaryAction)
+#else
                                   ) != KMessageBox::Yes)
+#endif
         mAutoStart->setChecked(true);
 }
 
@@ -973,7 +990,7 @@ void StorePrefTab::slotArchivedToggled(bool)
     if (keep  &&  !mOldKeepArchived  &&  mCheckKeepChanges
     &&  !Resources::getStandard(CalEvent::ARCHIVED, true).isValid())
     {
-        KAMessageBox::sorry(topLayout()->parentWidget(),
+        KAMessageBox::error(topLayout()->parentWidget(),
              xi18nc("@info", "<para>A default calendar is required in order to archive alarms, but none is currently enabled.</para>"
                   "<para>If you wish to keep expired alarms, please first use the calendars view to select a default "
                   "archived alarms calendar.</para>"));
@@ -2111,5 +2128,4 @@ void ViewPrefTab::slotWindowPosChanged(QAbstractButton* button)
 }
 #include "moc_prefdlg_p.cpp"
 #include "moc_prefdlg.cpp"
-
 // vim: et sw=4:
