@@ -18,6 +18,7 @@
 using namespace KAlarmCal;
 
 namespace KHolidays { class HolidayRegion; }
+class AkonadiPlugin;
 
 
 // Settings configured in the Preferences dialog
@@ -36,6 +37,22 @@ public:
     {
         QObject::connect(self(), signal, receiver, member);
     }
+
+    /** Return whether Akonadi plugin is available and should be used.
+     *  @see useAkonadiIfAvailable().
+     */
+    static bool             useAkonadi();
+
+    /** Return the Akonadi plugin.
+     *  @return the Akonadi plugin, or null if not available or not to be used.
+     */
+    static AkonadiPlugin*   akonadiPlugin();
+
+    /** Set whether to use the Akonadi plugin if available.
+     *  @see setUseAkonadiIfAvailable().
+     */
+    static void             setUseAkonadi(bool yes);
+
     static int              autoHideSystemTray();
     static void             setAutoHideSystemTray(int timeout);
     static bool             autoStartChangedByUser()         { return mAutoStartChangedByUser; }
@@ -66,8 +83,10 @@ public:
     static void             setQuitWarn(bool yes)            { setNotify(QUIT_WARN, yes); }
     static bool             confirmAlarmDeletion()           { return mUsingDefaults ? self()->base_ConfirmAlarmDeletion() : notifying(CONFIRM_ALARM_DELETION); }
     static void             setConfirmAlarmDeletion(bool yes){ setNotify(CONFIRM_ALARM_DELETION, yes); }
-    static bool             emailCopyToKMail()               { return self()->mBase_EmailCopyToKMail  &&  self()->mEmailClient == sendmail; }
-    static void             setEmailCopyToKMail(bool yes)    { self()->setBase_EmailCopyToKMail(yes); }
+    static MailClient       emailClient();
+    static void             setEmailClient(MailClient);
+    static bool             emailCopyToKMail();
+    static void             setEmailCopyToKMail(bool yes);
     static bool             emailQueuedNotify()              { return mUsingDefaults ? self()->base_EmailQueuedNotify() : notifying(EMAIL_QUEUED_NOTIFY); }
     static void             setEmailQueuedNotify(bool yes)   { setNotify(EMAIL_QUEUED_NOTIFY, yes); }
     static MailFrom         emailFrom();
