@@ -1,14 +1,14 @@
 /*
  *  calendarfunctions.h  -  miscellaneous calendar access functions
  *  Program:  kalarm
- *  SPDX-FileCopyrightText: 2020 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2020-2022 David Jarvie <djarvie@kde.org>
  *
  *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #pragma once
 
-#include <KAlarmCal/KAEvent>
+#include "kalarmcalendar/kaevent.h"
 
 #include <QHash>
 #include <QVector>
@@ -35,5 +35,4 @@ bool importCalendarFile(const QUrl& url, CalEvent::Types alarmTypes, bool newId,
 
 } // namespace KAlarm
 
-
 // vim: et sw=4:
