@@ -11,9 +11,6 @@
 #include "resourcedatamodelbase.h"
 #include "resources.h"
 #include "preferences.h"
-#include "lib/messagebox.h"
-#include "kalarm_debug.h"
-
 
 
 /*============================================================================*/
@@ -272,7 +269,7 @@ void AlarmListModel::setEventTypeFilter(CalEvent::Types types)
 */
 void AlarmListModel::setDateFilter(const QVector<QDate>& dates)
 {
-    QList<std::pair<KADateTime, KADateTime>> oldFilterDates = mFilterDates;
+    const QVector<std::pair<KADateTime, KADateTime>> oldFilterDates = mFilterDates;
     mFilterDates.clear();
     if (!dates.isEmpty())
     {
@@ -356,7 +353,7 @@ bool AlarmListModel::filterAcceptsRow(int sourceRow, const QModelIndex& sourcePa
                     {
                         // The event first occurs after the end of this date range.
                         // Find the next date range which it might be in.
-                        while (++i < count  &&  from > mFilterDates[i].second) ;
+                        while (++i < count  &&  from > mFilterDates[i].second) {}
                         if (i >= count)
                         {
                             resourceHash[ev.id()] = KADateTime();
@@ -432,10 +429,8 @@ QVariant AlarmListModel::data(const QModelIndex& ix, int role) const
                 switch (role)
                 {
                     case Qt::DisplayRole:
-#if 1
                     case ResourceDataModelBase::TimeDisplayRole:
                     case ResourceDataModelBase::SortRole:
-#endif
                     {
                         // Return a value based on the first occurrence in the date filter range.
                         const KAEvent ev = event(ix);
@@ -489,7 +484,7 @@ QVariant AlarmListModel::headerData(int section, Qt::Orientation orientation, in
     if (orientation == Qt::Horizontal)
     {
         if (section < 0  ||  section >= ColumnCount)
-            return QVariant();
+            return {};
     }
     return EventListModel::headerData(section, orientation, role);
 }
@@ -615,7 +610,7 @@ QVariant TemplateListModel::headerData(int section, Qt::Orientation orientation,
                 section = ResourceDataModelBase::TemplateNameColumn;
                 break;
             default:
-                return QVariant();
+                return {};
         }
     }
     return EventListModel::headerData(section, orientation, role);
