@@ -19,7 +19,7 @@
 #include <KLocalizedString>
 
 
-FileResource::FileResource(FileResourceSettings* settings)
+FileResource::FileResource(FileResourceSettings::Ptr settings)
     : ResourceType(settings->id())
     , mSettings(settings)
 {
@@ -352,6 +352,7 @@ bool FileResource::load(bool readThroughCache)
 
     if (!errorMessage.isEmpty())
         Resources::notifyResourceMessage(this, MessageType::Error, xi18nc("@info", "Error loading calendar <resource>%1</resource>.", displayName()), errorMessage);
+    setNewlyEnabled(false);
     return false;
 }
 
@@ -432,7 +433,8 @@ bool FileResource::save(QString* errorMessage, bool writeThroughCache, bool forc
                 if (errorMessage)
                 {
                     *errorMessage = msg + errMessage;
-                    errorMessage->replace(QRegularExpression(QStringLiteral("</html><html>")), QStringLiteral("<br><br>"));
+                    static const QRegularExpression re(QStringLiteral("</html><html>"));
+                    errorMessage->replace(re, QStringLiteral("<br><br>"));
                 }
                 else
                     Resources::notifyResourceMessage(this, MessageType::Error, msg, errMessage);
@@ -685,6 +687,7 @@ void FileResource::handleSettingsChange(Changes& changes)
             // types, changes are not processed when disabled calendar files
             // are updated. Also, when the calendar is loaded, disabled alarm
             // types are not fully processed by loaded().
+            setNewlyEnabled();   // ensure all events are notified
             load();
             changes |= Loaded;
         }
