@@ -1,5 +1,5 @@
 /*
- *  fileresourcemigrator.cpp  -  migrates or creates KAlarm non-Akonadi resources
+ *  fileresourcemigrator.cpp  -  migrates or creates KAlarm file system resources
  *  Program:  kalarm
  *  SPDX-FileCopyrightText: 2011-2022 David Jarvie <djarvie@kde.org>
  *
@@ -8,7 +8,6 @@
 
 #include "fileresourcemigrator.h"
 
-#include "collectionattribute.h"
 #include "dirresourceimportdialog.h"
 #include "preferences.h"
 #include "resources/calendarfunctions.h"
@@ -17,22 +16,15 @@
 #include "resources/resources.h"
 #include "lib/autoqpointer.h"
 #include "lib/desktop.h"
-#include "kalarmcalendar/version.h"
+#include "akonadiplugin/akonadiplugin.h"
 #include "kalarm_debug.h"
 
-#include <Akonadi/AgentManager>
-#include <Akonadi/AttributeFactory>
-#include <Akonadi/CollectionFetchJob>
-#include <Akonadi/CollectionFetchScope>
-#include <Akonadi/CollectionModifyJob>
-
-#include <KCalendarCore/MemoryCalendar>
-#include <KCalendarCore/ICalFormat>
-
 #include <KLocalizedString>
 #include <KConfig>
 #include <KConfigGroup>
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include <Kdelibs4Migration>
+#endif
 
 #include <QStandardPaths>
 #include <QDirIterator>
@@ -44,39 +36,9 @@ using namespace KAlarmCal;
 
 namespace
 {
-const QString KALARM_RESOURCE(QStringLiteral("akonadi_kalarm_resource"));
-const QString KALARM_DIR_RESOURCE(QStringLiteral("akonadi_kalarm_dir_resource"));
-
-// Holds an Akonadi collection's properties.
-struct CollectionProperties
-{
-    QColor          backgroundColour;
-    CalEvent::Types alarmTypes;
-    CalEvent::Types enabledTypes {CalEvent::EMPTY};
-    CalEvent::Types standardTypes {CalEvent::EMPTY};
-    bool            readOnly;
-
-    // Fetch the properties of a collection which has been fetched by CollectionFetchJob.
-    explicit CollectionProperties(const Akonadi::Collection&);
-};
-
-const Akonadi::Collection::Rights WritableRights = Akonadi::Collection::CanChangeItem | Akonadi::Collection::CanCreateItem | Akonadi::Collection::CanDeleteItem;
-
 bool readDirectoryResource(const QString& dirPath, CalEvent::Types alarmTypes, QHash<CalEvent::Type, QVector<KAEvent>>& events);
 }
 
-// Private class to provide private signals.
-class FileResourceMigrator::AkonadiMigration : public QObject
-{
-    Q_OBJECT
-public:
-    AkonadiMigration()  {}
-    void setComplete(bool needed)   { required = needed; Q_EMIT completed(required); }
-    bool required {false};
-Q_SIGNALS:
-    void completed(bool needed);
-};
-
 FileResourceMigrator* FileResourceMigrator::mInstance = nullptr;
 bool                  FileResourceMigrator::mCompleted = false;
 
@@ -85,14 +47,12 @@ bool                  FileResourceMigrator::mCompleted = false;
 */
 FileResourceMigrator::FileResourceMigrator(QObject* parent)
     : QObject(parent)
-    , mAkonadiMigration(new AkonadiMigration)
 {
 }
 
 FileResourceMigrator::~FileResourceMigrator()
 {
     qCDebug(KALARM_LOG) << "~FileResourceMigrator";
-    delete mAkonadiMigration;
     mInstance = nullptr;
 }
 
@@ -146,283 +106,135 @@ void FileResourceMigrator::start()
         // Some file system resources already exist, so no migration is
         // required. Create any missing default file system resources.
         mMigrateKResources = false;   // ignore KResources
-        akonadiMigrationComplete();
+        akonadiMigrationComplete(false);
     }
     else
     {
         // There are no file system resources, so migrate any Akonadi resources.
-        mAkonadiMigration->required = true;
-        connect(mAkonadiMigration, &FileResourceMigrator::AkonadiMigration::completed, this, &FileResourceMigrator::akonadiMigrationComplete);
-        connect(Akonadi::ServerManager::self(), &Akonadi::ServerManager::stateChanged, this, &FileResourceMigrator::checkAkonadiResources);
-        auto akstate = Akonadi::ServerManager::state();
-        mAkonadiStart = (akstate == Akonadi::ServerManager::NotRunning);
-        checkAkonadiResources(akstate);
-        // Migration of Akonadi collections has now been initiated. On
-        // completion, either KResource calendars will be migrated, or
-        // any missing default resources will be created.
-    }
-}
-
-/******************************************************************************
-* Called when the Akonadi server manager changes state.
-* Once it is running, migrate any Akonadi KAlarm resources.
-*/
-void FileResourceMigrator::checkAkonadiResources(Akonadi::ServerManager::State state)
-{
-    switch (state)
-    {
-        case Akonadi::ServerManager::Running:
-            migrateAkonadiResources();
-            break;
-
-        case Akonadi::ServerManager::Stopping:
-            // Wait until the server has stopped, so that we can restart it.
-            return;
-
-        default:
-            if (Akonadi::ServerManager::start())
-                return;   // wait for the server to change to Running state
-
-            // Can't start Akonadi, so give up trying to migrate.
-            qCWarning(KALARM_LOG) << "FileResourceMigrator::checkAkonadiResources: Failed to start Akonadi server";
-            mAkonadiMigration->setComplete(false);
-            break;
-    }
-
-    disconnect(Akonadi::ServerManager::self(), nullptr, this, nullptr);
-}
-
-/******************************************************************************
-* Initiate migration of Akonadi KAlarm resources.
-* Reply = true if migration initiated;
-*       = false if no KAlarm Akonadi resources found.
-*/
-void FileResourceMigrator::migrateAkonadiResources()
-{
-    qCDebug(KALARM_LOG) << "FileResourceMigrator::migrateAkonadiResources: initiated";
-    mCollectionPaths.clear();
-    mFetchesPending.clear();
-    Akonadi::AttributeFactory::registerAttribute<CollectionAttribute>();
-
-    // Create jobs to fetch all KAlarm Akonadi collections.
-    const Akonadi::AgentInstance::List agents = Akonadi::AgentManager::self()->instances();
-    for (const Akonadi::AgentInstance& agent : agents)
-    {
-        const QString type = agent.type().identifier();
-        if (type == KALARM_RESOURCE  ||  type == KALARM_DIR_RESOURCE)
-        {
-            Akonadi::CollectionFetchJob* job = new Akonadi::CollectionFetchJob(Akonadi::Collection::root(), Akonadi::CollectionFetchJob::FirstLevel);
-            job->fetchScope().setResource(agent.identifier());
-            mFetchesPending[job] = (type == KALARM_DIR_RESOURCE);
-            connect(job, &KJob::result, this, &FileResourceMigrator::collectionFetchResult);
-
-            mMigrateKResources = false;   // Akonadi resources exist, so ignore KResources
-        }
-    }
-    if (mFetchesPending.isEmpty())
-        mAkonadiMigration->setComplete(false);   // there are no Akonadi resources to migrate
-}
-
-/******************************************************************************
-* Called when an Akonadi collection fetch job has completed.
-* Check for, and remove, any Akonadi resources which duplicate use of calendar
-* files/directories.
-*/
-void FileResourceMigrator::collectionFetchResult(KJob* j)
-{
-    auto job = qobject_cast<Akonadi::CollectionFetchJob*>(j);
-    const QString id = job->fetchScope().resource();
-    if (j->error())
-        qCCritical(KALARM_LOG) << "FileResourceMigrator::collectionFetchResult: CollectionFetchJob" << id << "error: " << j->errorString();
-    else
-    {
-        const Akonadi::Collection::List collections = job->collections();
-        if (collections.isEmpty())
-            qCCritical(KALARM_LOG) << "FileResourceMigrator::collectionFetchResult: No collections found for resource" << id;
+        mAkonadiPlugin = Preferences::akonadiPlugin();
+        if (!mAkonadiPlugin)
+            akonadiMigrationComplete(false);   // Akonadi plugin is not available
         else
         {
-            // Note that a KAlarm Akonadi agent contains only one collection.
-            const Akonadi::Collection& collection(collections[0]);
-            const bool dirType = mFetchesPending.value(job, false);
-            const AkResourceData thisRes(job->fetchScope().resource(), collection, dirType);
-            bool saveThis = true;
-            auto it = mCollectionPaths.constFind(collection.remoteId());
-            if (it != mCollectionPaths.constEnd())
-            {
-                // Remove the resource which, in decreasing order of priority:
-                // - Is disabled;
-                // - Is not a standard resource;
-                // - Contains the higher numbered Collection ID, which is likely
-                //   to be the more recently created.
-                const AkResourceData prevRes = it.value();
-                const CollectionProperties properties[2] = { CollectionProperties(prevRes.collection),
-                                                             CollectionProperties(thisRes.collection) };
-                int propToUse = (thisRes.collection.id() < prevRes.collection.id()) ? 1 : 0;
-                if (properties[1 - propToUse].standardTypes  &&  !properties[propToUse].standardTypes)
-                    propToUse = 1 - propToUse;
-                if (properties[1 - propToUse].enabledTypes  &&  !properties[propToUse].enabledTypes)
-                    propToUse = 1 - propToUse;
-                saveThis = (propToUse == 1);
-
-                const auto resourceToRemove = saveThis ? prevRes.resourceId : thisRes.resourceId;
-                qCWarning(KALARM_LOG) << "FileResourceMigrator::collectionFetchResult: Removing duplicate resource" << resourceToRemove;
-                Akonadi::AgentManager* agentManager = Akonadi::AgentManager::self();
-                agentManager->removeInstance(agentManager->instance(resourceToRemove));
-            }
-            if (saveThis)
-                mCollectionPaths[collection.remoteId()] = thisRes;
+            connect(mAkonadiPlugin, &AkonadiPlugin::akonadiMigrationComplete, this, &FileResourceMigrator::akonadiMigrationComplete);
+            connect(mAkonadiPlugin, &AkonadiPlugin::migrateFileResource, this, &FileResourceMigrator::migrateFileResource);
+            connect(mAkonadiPlugin, &AkonadiPlugin::migrateDirResource, this, &FileResourceMigrator::migrateDirResource);
+            mAkonadiPlugin->initiateAkonadiResourceMigration();
+            // Migration of Akonadi collections has now been initiated. On
+            // completion, either KResource calendars will be migrated, or
+            // any missing default resources will be created.
         }
     }
-    mFetchesPending.remove(job);
-    if (mFetchesPending.isEmpty())
-    {
-        // De-duplication is complete. Migrate the remaining Akonadi resources.
-        doMigrateAkonadiResources();
-    }
 }
 
 /******************************************************************************
-* Migrate Akonadi KAlarm resources to file system resources.
+* Migrate one Akonadi single file collection to a file system resource.
 */
-void FileResourceMigrator::doMigrateAkonadiResources()
+void FileResourceMigrator::migrateFileResource(const QString& resourceName,
+                      const QUrl& location, CalEvent::Types alarmTypes,
+                      const QString& displayName, const QColor& backgroundColour,
+                      CalEvent::Types enabledTypes, CalEvent::Types standardTypes,
+                      bool readOnly)
 {
-    qCDebug(KALARM_LOG) << "FileResourceMigrator::doMigrateAkonadiResources";
+    FileResourceSettings::Ptr settings(new FileResourceSettings(
+                  FileResourceSettings::File, location, alarmTypes, displayName,
+                  backgroundColour, enabledTypes, standardTypes, readOnly));
+    Resource resource = FileResourceConfigManager::addResource(settings);
 
-    // First, migrate KAlarm calendar file Akonadi resources.
-    // This will allow any KAlarm directory resources to be merged into
-    // single file resources, if the user prefers that.
-    for (auto it = mCollectionPaths.constBegin();  it != mCollectionPaths.constEnd();  ++it)
-    {
-        const AkResourceData& resourceData = it.value();
-        if (!resourceData.dirType)
-            migrateAkonadiCollection(resourceData.collection, false);
-    }
+    // Update the calendar to the current KAlarm format if necessary,
+    // and if the user agrees.
+    auto updater = new FileResourceCalendarUpdater(resource, true, this);
+    connect(updater, &QObject::destroyed, this, &FileResourceMigrator::checkIfComplete);
+    updater->update();   // note that 'updater' will auto-delete when finished
 
-    // Now migrate KAlarm directory Akonadi resources, which must be merged
-    // or converted into single file resources.
-    for (auto it = mCollectionPaths.constBegin();  it != mCollectionPaths.constEnd();  ++it)
-    {
-        const AkResourceData& resourceData = it.value();
-        if (resourceData.dirType)
-            migrateAkonadiCollection(resourceData.collection, true);
-    }
+    mExistingAlarmTypes |= alarmTypes;
 
-    // The alarm types of all collections have been found.
-    mCollectionPaths.clear();
-    mAkonadiMigration->setComplete(true);
-}
-
-/******************************************************************************
-* Migrate one Akonadi collection to a file system resource.
-*/
-void FileResourceMigrator::migrateAkonadiCollection(const Akonadi::Collection& collection, bool dirType)
-{
-    // Fetch the collection's properties.
-    const CollectionProperties colProperties(collection);
-
-    bool converted = false;
-    if (!dirType)
-    {
-        // It's a single file resource.
-        qCDebug(KALARM_LOG) << "FileResourceMigrator: Creating resource" << collection.displayName() << ", alarm types:" << colProperties.alarmTypes << ", standard types:" << colProperties.standardTypes;
-        FileResourceSettings::Ptr settings(new FileResourceSettings(
-                      FileResourceSettings::File,
-                      QUrl::fromUserInput(collection.remoteId(), QString(), QUrl::AssumeLocalFile),
-                      colProperties.alarmTypes, collection.displayName(), colProperties.backgroundColour,
-                      colProperties.enabledTypes, colProperties.standardTypes, colProperties.readOnly));
-        Resource resource = FileResourceConfigManager::addResource(settings);
-
-        // Update the calendar to the current KAlarm format if necessary,
-        // and if the user agrees.
-        auto updater = new FileResourceCalendarUpdater(resource, true, this);
-        connect(updater, &QObject::destroyed, this, &FileResourceMigrator::checkIfComplete);
-        updater->update();   // note that 'updater' will auto-delete when finished
-
-        mExistingAlarmTypes |= colProperties.alarmTypes;
-        converted = true;
-    }
-    else
-    {
-        // Convert Akonadi directory resource to single file resources.
-
-        // Use AutoQPointer to guard against crash on application exit while
-        // the dialogue is still open. It prevents double deletion (both on
-        // deletion of parent, and on return from this function).
-        AutoQPointer<DirResourceImportDialog> dlg = new DirResourceImportDialog(collection.displayName(), collection.remoteId(), colProperties.alarmTypes, Desktop::mainWindow());
-        if (dlg->exec() == QDialog::Accepted)
-        {
-            if (dlg)
-            {
-                QHash<CalEvent::Type, QVector<KAEvent>> events;
-                readDirectoryResource(collection.remoteId(), colProperties.alarmTypes, events);
-
-                for (auto it = events.constBegin();  it != events.constEnd();  ++it)
-                {
-                    const CalEvent::Type alarmType = it.key();
-                    Resource resource;
-                    const ResourceId id = dlg->resourceId(alarmType);
-                    if (id >= 0)
-                    {
-                        // The directory resource's alarms are to be
-                        // imported into an existing resource.
-                        resource = Resources::resource(id);
-                    }
-                    else
-                    {
-                        const QUrl destUrl = dlg->url(alarmType);
-                        if (!destUrl.isValid())
-                            continue;   // this alarm type is not to be imported
-
-                        // The directory resource's alarms are to be
-                        // imported into a new resource.
-                        qCDebug(KALARM_LOG) << "FileResourceMigrator: Creating resource" << dlg->displayName(alarmType) << ", type:" << alarmType << ", standard:" << (bool)(colProperties.standardTypes & alarmType);
-                        FileResourceSettings::Ptr settings(new FileResourceSettings(
-                                      FileResourceSettings::File, destUrl, alarmType,
-                                      dlg->displayName(alarmType), colProperties.backgroundColour,
-                                      colProperties.enabledTypes, (colProperties.standardTypes & alarmType), colProperties.readOnly));
-                        resource = FileResourceConfigManager::addResource(settings);
-                    }
-
-                    // Add directory events of the appropriate type to this resource.
-                    for (const KAEvent& event : std::as_const(it.value()))
-                        resource.addEvent(event);
-
-                    mExistingAlarmTypes |= alarmType;
-                    converted = true;
-                }
-            }
-        }
-    }
-
-    if (converted)
+    if (mAkonadiPlugin)
     {
         // Delete the Akonadi resource, to prevent it using CPU, on the
         // assumption that Akonadi access won't be needed by any other
         // application. Excess CPU usage is one of the major bugs which
         // prompted replacing Akonadi resources with file resources.
-        Akonadi::AgentManager* agentManager = Akonadi::AgentManager::self();
-        const Akonadi::AgentInstance agent = agentManager->instance(collection.resource());
-        agentManager->removeInstance(agent);
+        mAkonadiPlugin->deleteAkonadiResource(resourceName);
+    }
+}
+
+/******************************************************************************
+* Migrate one Akonadi directory collection to file system resources.
+*/
+void FileResourceMigrator::migrateDirResource(const QString& resourceName,
+                      const QString& path, CalEvent::Types alarmTypes,
+                      const QString& displayName, const QColor& backgroundColour,
+                      CalEvent::Types enabledTypes, CalEvent::Types standardTypes,
+                      bool readOnly)
+{
+    // Use AutoQPointer to guard against crash on application exit while
+    // the dialogue is still open. It prevents double deletion (both on
+    // deletion of parent, and on return from this function).
+    AutoQPointer<DirResourceImportDialog> dlg = new DirResourceImportDialog(displayName, path, alarmTypes, Desktop::mainWindow());
+    if (dlg->exec() == QDialog::Accepted)
+    {
+        if (dlg)
+        {
+            bool converted = false;
+            QHash<CalEvent::Type, QVector<KAEvent>> events;
+            readDirectoryResource(path, alarmTypes, events);
+
+            for (auto it = events.constBegin();  it != events.constEnd();  ++it)
+            {
+                const CalEvent::Type alarmType = it.key();
+                Resource resource;
+                const ResourceId id = dlg->resourceId(alarmType);
+                if (id >= 0)
+                {
+                    // The directory resource's alarms are to be
+                    // imported into an existing resource.
+                    resource = Resources::resource(id);
+                }
+                else
+                {
+                    const QUrl destUrl = dlg->url(alarmType);
+                    if (!destUrl.isValid())
+                        continue;   // this alarm type is not to be imported
+
+                    // The directory resource's alarms are to be
+                    // imported into a new resource.
+                    qCDebug(KALARM_LOG) << "FileResourceMigrator: Creating resource" << dlg->displayName(alarmType) << ", type:" << alarmType << ", standard:" << (bool)(standardTypes & alarmType);
+                    FileResourceSettings::Ptr settings(new FileResourceSettings(
+                                  FileResourceSettings::File, destUrl, alarmType,
+                                  dlg->displayName(alarmType), backgroundColour,
+                                  enabledTypes, (standardTypes & alarmType), readOnly));
+                    resource = FileResourceConfigManager::addResource(settings);
+                }
+
+                // Add directory events of the appropriate type to this resource.
+                for (const KAEvent& event : std::as_const(it.value()))
+                    resource.addEvent(event);
+
+                mExistingAlarmTypes |= alarmType;
+                converted = true;
+            }
+
+            if (converted  &&  mAkonadiPlugin)
+            {
+                // Delete the Akonadi resource, to prevent it using CPU, on the
+                // assumption that Akonadi access won't be needed by any other
+                // application. Excess CPU usage is one of the major bugs which
+                // prompted replacing Akonadi resources with file resources.
+                mAkonadiPlugin->deleteAkonadiResource(resourceName);
+            }
+        }
     }
 }
 
 /******************************************************************************
 * Called when Akonadi migration is complete or is known not to be possible.
 */
-void FileResourceMigrator::akonadiMigrationComplete()
+void FileResourceMigrator::akonadiMigrationComplete(bool migrated)
 {
-    // Ignore any further Akonadi server state changes, to prevent possible
-    // repeated migrations.
-    disconnect(Akonadi::ServerManager::self(), nullptr, this, nullptr);
-
-    if (mAkonadiStart)
-    {
-        // The Akonadi server wasn't running before we started it, so stop it
-        // now that it's no longer needed.
-        Akonadi::ServerManager::stop();
-    }
-
-    if (!mAkonadiMigration->required)
+    if (migrated)
+        mMigrateKResources = false;
+    else
     {
         // There are no Akonadi resources, so migrate any KResources alarm
         // calendars from pre-Akonadi versions of KAlarm.
@@ -461,12 +273,15 @@ void FileResourceMigrator::migrateKResources()
         QString configFile = QStandardPaths::locate(QStandardPaths::ConfigLocation, kresConfFile);
         if (configFile.isEmpty())
         {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
             Kdelibs4Migration kde4;
             if (!kde4.kdeHomeFound())
                 return;    // can't find $KDEHOME
             configFile = kde4.locateLocal("config", kresConfFile);
             if (configFile.isEmpty())
                 return;    // can't find KResources config file
+
+#endif
         }
         qCDebug(KALARM_LOG) << "FileResourceMigrator::migrateKResources";
         const KConfig config(configFile, KConfig::SimpleConfig);
@@ -591,22 +406,6 @@ void FileResourceMigrator::createCalendar(CalEvent::Type alarmType, const QStrin
 namespace
 {
 
-/******************************************************************************
-* Fetch an Akonadi collection's properties.
-*/
-CollectionProperties::CollectionProperties(const Akonadi::Collection& collection)
-{
-    readOnly   = (collection.rights() & WritableRights) != WritableRights;
-    alarmTypes = CalEvent::types(collection.contentMimeTypes());
-    if (collection.hasAttribute<CollectionAttribute>())
-    {
-        const auto* attr = collection.attribute<CollectionAttribute>();
-        enabledTypes     = attr->enabled() & alarmTypes;
-        standardTypes    = attr->standard() & enabledTypes;
-        backgroundColour = attr->backgroundColor();
-    }
-}
-
 /******************************************************************************
 * Load and parse events from each file in a calendar directory.
 */
@@ -642,6 +441,4 @@ bool readDirectoryResource(const QString& dirPath, CalEvent::Types alarmTypes, Q
 
 }
 
-#include "fileresourcemigrator.moc"
-
 // vim: et sw=4:
