@@ -10,7 +10,6 @@
 
 #include "resourcedatamodelbase.h"
 #include "resources.h"
-#include "preferences.h"
 #include "lib/messagebox.h"
 #include "kalarm_debug.h"
 
@@ -342,7 +341,7 @@ bool ResourceCheckListModel::setData(const QModelIndex& index, const QVariant& v
             }
             if (!errmsg.isEmpty())
             {
-                KAMessageBox::sorry(messageParent, errmsg);
+                KAMessageBox::error(messageParent, errmsg);
                 return false;
             }
         }
@@ -677,7 +676,8 @@ bool ResourceView::viewportEvent(QEvent* e)
             int i = toolTip.indexOf(QLatin1Char('@'));
             if (i > 0)
             {
-                const int j = toolTip.indexOf(QRegExp(QLatin1String("<(nl|br)"), Qt::CaseInsensitive), i + 1);
+                static const QRegularExpression re(QStringLiteral("<(nl|br)"), QRegularExpression::CaseInsensitiveOption);
+                const int j = toolTip.indexOf(re, i + 1);
                 const int k = toolTip.indexOf(QLatin1Char('@'), j);
                 const QString name = toolTip.mid(i + 1, j - i - 1);
                 value = model()->data(index, Qt::FontRole);
@@ -721,4 +721,5 @@ QStyleOptionViewItem ResourceView::listViewOptions() const
     return option;
 #endif
 }
+
 // vim: et sw=4:
