@@ -1,22 +1,23 @@
 /*
  *  soundpicker.cpp  -  widget to select a sound file or a beep
  *  Program:  kalarm
- *  SPDX-FileCopyrightText: 2002-2021 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2002-2022 David Jarvie <djarvie@kde.org>
  *
  *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "soundpicker.h"
 
-#include "kalarmapp.h"
 #include "sounddlg.h"
 #include "lib/autoqpointer.h"
 #include "lib/combobox.h"
 #include "lib/file.h"
 #include "lib/pushbutton.h"
-#include "kalarm_debug.h"
 
+#include <kpimtextedit/kpimtextedit-texttospeech.h>
+#if KPIMTEXTEDIT_TEXT_TO_SPEECH
 #include <KPIMTextEdit/TextToSpeech>
+#endif
 
 #include <KLocalizedString>
 #include <phonon/backendcapabilities.h>
@@ -130,7 +131,9 @@ void SoundPicker::showFile(bool show)
 */
 void SoundPicker::showSpeak(bool show)
 {
+#if KPIMTEXTEDIT_TEXT_TO_SPEECH
     if (!KPIMTextEdit::TextToSpeech::self()->isReady())
+#endif
         show = false;    // speech capability is not installed or configured
     if (show != mSpeakShowing)
     {
@@ -154,6 +157,10 @@ Preferences::SoundType SoundPicker::sound() const
 {
     if (mTypeCombo->currentIndex() < 0)
         return Preferences::Sound_None;
+#if !KPIMTEXTEDIT_TEXT_TO_SPEECH
+    if (mTypeCombo->currentData().toInt() == Preferences::Sound_Speak)
+        return Preferences::Sound_None;
+#endif
     return static_cast<Preferences::SoundType>(mTypeCombo->currentData().toInt());
 }
 
