@@ -10,16 +10,14 @@
 
 #include "functions.h"
 #include "newalarmaction.h"
-#include "resourcescalendar.h"
 #include "templatelistview.h"
 #include "undo.h"
 #include "resources/datamodel.h"
-#include "resources/resources.h"
 #include "resources/eventmodel.h"
+#include "resources/resources.h"
 #include "lib/config.h"
 #include "lib/messagebox.h"
 #include "lib/shellprocess.h"
-#include "kalarm_debug.h"
 
 #include <KLocalizedString>
 #include <KGuiItem>
@@ -28,11 +26,12 @@
 #include <KSeparator>
 
 #include <QAction>
-#include <QPushButton>
-#include <QVBoxLayout>
-#include <QHBoxLayout>
 #include <QBoxLayout>
+#include <QHBoxLayout>
+#include <QPushButton>
 #include <QResizeEvent>
+#include <QVBoxLayout>
+#include <QMenu>
 
 using namespace KCal;
 
